@@ -8,7 +8,6 @@
 
 #include <config.h>
 
-#include "e-data-book-marshal.h"
 #include "e-data-book-view.h"
 #include "e-book-backend.h"
 
@@ -19,7 +18,7 @@ struct _EBookBackendPrivate {
 	GList *clients;
 
 	ESource *source;
-	gboolean loaded, writable, removed;
+	gboolean loaded, writable, removed, online;
 
 	GMutex *views_mutex;
 	EList *views;
@@ -124,6 +123,7 @@ e_book_backend_open (EBookBackend *backend,
 			book, opid, GNOME_Evolution_Addressbook_Success);
 
 		e_data_book_report_writable (book, backend->priv->writable);
+		e_data_book_report_connection_status (book, backend->priv->online);
 	} else {
 		GNOME_Evolution_Addressbook_CallStatus status =
 			e_book_backend_load_source (backend, e_data_book_get_source (book), only_if_exists);
@@ -132,6 +132,7 @@ e_book_backend_open (EBookBackend *backend,
 
 		if (status == GNOME_Evolution_Addressbook_Success || status == GNOME_Evolution_Addressbook_InvalidServerVersion)
 			e_data_book_report_writable (book, backend->priv->writable);
+			e_data_book_report_connection_status (book, backend->priv->online);
 	}
 
 	g_mutex_unlock (backend->priv->open_mutex);
@@ -779,6 +780,23 @@ e_book_backend_set_mode (EBookBackend *backend,
 
 }
 
+/**
+ * e_book_backend_sync:
+ * @backend: an #EBookbackend
+ *
+ * Write all pending data to disk.  This is only required under special
+ * circumstances (for example before a live backup) and should not be used in
+ * normal use.
+ */
+void 
+e_book_backend_sync (EBookBackend *backend)
+{
+	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
+	
+	if (E_BOOK_BACKEND_GET_CLASS (backend)->sync)
+		(* E_BOOK_BACKEND_GET_CLASS (backend)->sync) (backend);
+}
+
 /**
  * e_book_backend_change_add_new:
  * @vcard: a VCard string
@@ -978,6 +996,7 @@ e_book_backend_notify_connection_status (EBookBackend *backend, gboolean is_onli
 	GList *clients;
 	
 	priv = backend->priv;
+	priv->online = is_online;
 	g_mutex_lock (priv->clients_mutex);
 	
 	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
@@ -1067,7 +1086,7 @@ e_book_backend_class_init (EBookBackendClass *klass)
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (EBookBackendClass, last_client_gone),
 			      NULL, NULL,
-			      e_data_book_marshal_NONE__NONE,
+			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
 }
 
