@@ -22,34 +22,35 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
 #include <config.h>
+#endif
 
-/* (from glibc headers:
-   POSIX says that <sys/types.h> must be included (by the caller) before <regex.h>.  */
+/* POSIX requires <sys/types.h> be included before <regex.h> */
+#include <sys/types.h>
 
+#include <ctype.h>
+#include <errno.h>
+#include <fcntl.h>
+#include <regex.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <sys/types.h>
-#include <regex.h>
 #include <string.h>
 #include <unistd.h>
-#include <ctype.h>
-#include <fcntl.h>
-#include <errno.h>
-
-#include <glib.h>
 
 #ifndef G_OS_WIN32
 #include <sys/wait.h>
 #endif
 
-#include "libedataserver/e-sexp.h"
-#include "libedataserver/e-iconv.h"
+#include <glib.h>
+#include <glib/gi18n-lib.h>
+
+#include <libedataserver/e-iconv.h>
+#include <libedataserver/e-sexp.h>
 
 #include "camel-debug.h"
 #include "camel-exception.h"
 #include "camel-filter-search.h"
-#include "camel-i18n.h"
 #include "camel-mime-message.h"
 #include "camel-multipart.h"
 #include "camel-provider.h"
@@ -533,7 +534,6 @@ child_watch (GPid     pid,
 	g_spawn_close_pid (pid);
 
 	child_watch_data->child_status = status;
-
 	g_main_loop_quit (child_watch_data->loop);
 }
 
@@ -549,6 +549,7 @@ run_command (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessa
 	GPtrArray *args;
 	child_watch_data_t child_watch_data;
 	GSource *source;
+	GMainContext *context;
 	
 	if (argc < 1 || argv[0]->value.string[0] == '\0')
 		return 0;
@@ -590,7 +591,9 @@ run_command (struct _ESExp *f, int argc, struct _ESExpResult **argv, FilterMessa
 	camel_stream_flush (stream);
 	camel_object_unref (stream);
 	
-	child_watch_data.loop = g_main_loop_new (g_main_context_new (), FALSE);
+	context = g_main_context_new ();
+	child_watch_data.loop = g_main_loop_new (context, FALSE);
+	g_main_context_unref (context);
 
 	source = g_child_watch_source_new (child_pid);
 	g_source_set_callback (source, (GSourceFunc) child_watch, &child_watch_data, NULL);
