@@ -64,6 +64,7 @@
 #include "xntlm.h"
 
 #include <libedataserver/e-data-server-util.h>
+#include <libedataserver/e-url.h>
 #include <libedataserverui/e-passwords.h>
 #include <gconf/gconf-client.h>
 #include <libxml/tree.h>
@@ -442,7 +443,9 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 
 	/* A redirection to "logon.asp" means this is Exchange 5.5
 	 * OWA. A redirection to "owalogon.asp" means this is Exchange
-	 * 2003 forms-based authentication. Other redirections most
+	 * 2003 forms-based authentication. A redirection to
+	 * "CookieAuth.dll" means that it's an Exchange 2003 server
+	 * behind an ISA Server 2004 proxy. Other redirections most
 	 * likely indicate that the user's mailbox has been moved to a
 	 * new server.
 	 */
@@ -460,7 +463,8 @@ e2k_autoconfig_get_context (E2kAutoconfig *ac, E2kOperation *op,
 		if (strstr (location, "/logon.asp")) {
 			*result = E2K_AUTOCONFIG_EXCHANGE_5_5;
 			goto done;
-		} else if (strstr (location, "/owalogon.asp")) {
+		} else if (strstr (location, "/owalogon.asp") ||
+			   strstr (location, "/CookieAuth.dll")) {
 			if (e2k_context_fba (ctx, msg))
 				goto try_again;
 			*result = E2K_AUTOCONFIG_AUTH_ERROR;
@@ -1620,7 +1624,7 @@ validate (const char *owa_url, char *user, char *password, ExchangeParams *excha
 }
 
 gboolean
-e2k_validate_user (const char *owa_url, char **user,
+e2k_validate_user (const char *owa_url, char *pkey, char **user,
 		   ExchangeParams *exchange_params, gboolean *remember_password,
 		   E2kAutoconfigResult *result)
 {
@@ -1629,11 +1633,16 @@ e2k_validate_user (const char *owa_url, char **user,
 	char *username;
 	gchar **usernames;
 	int try = 0;
+	EUri *uri;
 
+	uri = e_uri_new (owa_url);
+	key = g_strdup_printf ("%s%s/", pkey, uri->host); /* FIXME */
+	e_uri_free (uri);
+	
 try_auth_again:
 	username = g_strdup (*user);
 
-	key = g_strdup_printf ("%s//%s@%s/", "exchange:", username, owa_url); /* FIXME */
+
 	password = e_passwords_get_password ("Exchange", key);
 	if (password) {
 		/* This can be the case, where user presses authenticate button and
